@@ -70,6 +70,9 @@ class ScenarioAwareTestCaseIdStrReprMixIn(object):
                 self._testMethodName,
                 self._testScenarioName)
 
+    def __hash__(self):
+        return hash(repr(self))
+
     def shortDescription(self):
         # XXX this makes setup.py test and test_project/manage.py test
         # output consistent but I have not managed to understand why
